[][src]Enum script::dom::bindings::guard::Condition

pub enum Condition {
    Func(fn(_: JSContext, _: HandleObject) -> bool),
    Pref(&'static str),
    Exposed(Globals),
    Satisfied,
}

A condition to expose things.

Variants

Func(fn(_: JSContext, _: HandleObject) -> bool)

The condition is satisfied if the function returns true.

Pref(&'static str)

The condition is satisfied if the preference is set.

Exposed(Globals)
Satisfied

The condition is always satisfied.

Implementations

impl Condition[src]

pub fn is_satisfied(
    &self,
    cx: JSContext,
    obj: HandleObject,
    global: HandleObject
) -> bool
[src]